## scRNA-seq Data Sampling Toolkit

[Document](https://scdesign.readthedocs.io/en/latest/index.html) | 
[PyPI](https://pypi.org/project/scSAMP)

### Method Design
1. Factor calculation
2. Ratio balance
3. Sampling strategy
4. Sampling amount

### Validation 
1. Model metrics: whole dataset + cluster-specific
2. Model usage:
   - SVM with rbf kernel
   - ACTINN (Neural Network)
3. Bias: reduced reference dataset

### Usage
